UyavaDiagnosticLevel enum
Severity levels for graph diagnostics emitted by Uyava.
These map to UI affordances (icons/color) in DevTools/Desktop.
- Inheritance
- Available extensions
Values
- info → const UyavaDiagnosticLevel
- warning → const UyavaDiagnosticLevel
- error → const UyavaDiagnosticLevel
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toWireString(
) → String -
Available on UyavaDiagnosticLevel, provided by the UyavaDiagnosticLevelWire extension
Wire-friendly string representation (lowercase enum name).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
UyavaDiagnosticLevel> - A constant List of the values in this enum, in order of their declaration.