UyavaDeduplicationResult<T> class

Properties

duplicates List<UyavaDuplicateRecord>
Metadata describing which entries were replaced by newer payloads.
final
hasDuplicates bool
no setter
hashCode int
The hash code for this object.
no setterinherited
latestById Map<String, UyavaDeduplicatedEntry<T>>
Map of identifier to the latest payload + index (last writer wins).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited